# -*- coding: utf-8 -*-

from django.core.management.base import NoArgsCommand
from django.db import transaction

from acomea.flussi.models import Metric, MetricItem, MetricDay, MetricWeek
from acomea.flussi.models import MetricMonth, MetricYear , MetricUserDay
from acomea.flussi.models import MetricUserWeek, MetricUserMonth, MetricUserYear

from acomea.flussi.utils import week_for_date, month_for_date, year_for_date, get_backend


class Command(NoArgsCommand):
    help = "Aggregate Application Metrics"

    requires_model_validation = True

    @transaction.commit_manually
    def handle_noargs(self, **options):



        """ Aggregate Application Metrics """

        try:
            backend = get_backend()

            # If using Mixpanel this command is a NOOP
            if backend == 'app_metrics.backends.mixpanel':
                print "Useless use of metrics_aggregate when using Mixpanel backend"
                return

            # Aggregate Items
            items = MetricItem.objects.all()

            for metric_item in items:
                # Daily Aggregation
                metric_day, created = MetricDay.objects.get_or_create(
                    metric=metric_item.metric,
                    created=metric_item.datetime_created
                )

                metric_day.num += metric_item.num
                metric_day.save()

                if metric_item.user:
                    metric_user_day, created = MetricUserDay.objects.get_or_create(
                        metric=metric_item.metric,
                        created=metric_item.datetime_created,
                        user=metric_item.user
                    )

                    metric_user_day.num += metric_item.num
                    metric_user_day.save()

                # Weekly Aggregation
                week_date = week_for_date(metric_item.datetime_created)
                metric_week, created = MetricWeek.objects.get_or_create(
                    metric=metric_item.metric,
                    created=week_date
                )

                metric_week.num += metric_item.num
                metric_week.save()

                if metric_item.user:
                    metric_user_week, created = MetricUserWeek.objects.get_or_create(
                        metric=metric_item.metric,
                        created=week_date,
                        user=metric_item.user
                    )

                    metric_user_week.num += metric_item.num
                    metric_user_week.save()

                # Monthly Aggregation
                month_date = month_for_date(metric_item.datetime_created)
                metric_month, created = MetricMonth.objects.get_or_create(
                    metric=metric_item.metric,
                    created=month_date,
                )
                metric_month.num += metric_item.num
                metric_month.save()

                if metric_item.user:
                    metric_user_month, created = MetricUserMonth.objects.get_or_create(
                        metric=metric_item.metric,
                        created=month_date,
                        user=metric_item.user
                    )
                    metric_user_month.num += metric_item.num
                    metric_user_month.save()

                # Yearly Aggregation
                year_date = year_for_date(metric_item.datetime_created)
                metric_year, created = MetricYear.objects.get_or_create(
                    metric=metric_item.metric,
                    created=year_date,
                )
                metric_year.num += metric_item.num
                metric_year.save()

                if metric_item.user:
                    metric_user_year, created = MetricUserYear.objects.get_or_create(
                        metric=metric_item.metric,
                        created=year_date,
                        user=metric_item.user
                    )
                    metric_user_year.num += metric_item.num
                    metric_user_year.save()

            # Kill off our items
            items.delete()
            transaction.commit()

        except Exception, e:
            transaction.rollback()
            print e
