#! -*- coding: utf-8 -*-
import datetime

from django.conf import settings
from django.http import HttpResponseForbidden
from django.shortcuts import render_to_response
from django.template import RequestContext
from django.contrib.auth.decorators import login_required

from .models import Metric
from acomea.utenti.models import AcomeaProfiles


def flusso_utenti(request, anno=None, mese=None, giorno=None):

    # IP sorgente richiesta
    if 'HTTP_X_FORWARDED_FOR' in request.META:
        source_ip = request.META['HTTP_X_FORWARDED_FOR']
    else:
        source_ip = request.META['REMOTE_ADDR']

    if source_ip in settings.IP_GET_FLUSSI:
        profiles = AcomeaProfiles.objects.all()
        if anno and mese and giorno:
            profiles = profiles.filter(ultima_modifica__gte=datetime.date(int(anno), int(mese), int(giorno)))
        return render_to_response('flussi/flusso_utenti.html', locals(), RequestContext(request))
    return HttpResponseForbidden()


def flusso_metriche(request, aggregation, slug, anno=None, mese=None, giorno=None):
    """Torna la lista di aggregati per una metrica, dove 'aggregation' è il nome
    della classe aggregato e slug lo slug della Metric voluta.
    """
    if request.META.has_key('HTTP_X_FORWARDED_FOR'):
        source_ip = request.META['HTTP_X_FORWARDED_FOR']
    else:
        source_ip = request.META['REMOTE_ADDR']
    if source_ip in settings.IP_GET_FLUSSI:

        try:
            mod = __import__('acomea.flussi.models', globals(), locals(), [aggregation])
            classe_aggregato = getattr(mod, aggregation)
            if slug:
                if Metric.objects.filter(slug__exact=slug).count() == 0:
                    error = "EmptyQueryset"
                    error_hint = "non esiste un tipo di metrica con questo slug"
                items = classe_aggregato.objects.filter(metric__slug=slug)
            else:
                items = classe_aggregato.objects.all()
            if anno and mese and giorno:
                items = items.filter(created__exact=datetime.date(int(anno), int(mese), int(giorno)))
        except AttributeError:
            error = "AttributeError"
            error_hint = "non esiste un tipo di aggregato con questo nome."
        except Exception, e:
            error = str(e)
            error_hint = "errore inatteso, apri un ticket."
        return render_to_response('flussi/flusso_metriche.html', locals(), RequestContext(request))
    return HttpResponseForbidden()


@login_required
def metric_report_view(request):
    return render_to_response('app_metrics/reports.html', {}, context_instance=RequestContext(request))